$.jqplot.LogAxisRenderer

A plugin for a jqPlot to render a logarithmic axis.

To use this renderer, include the plugin in your source

>     <script type="text/javascript" language="javascript" src="plugins/jqplot.logAxisRenderer.js"></script>

and supply the appropriate options to your plot

>     {axes:{xaxis:{renderer:$.jqplot.LogAxisRenderer}}}

Summary

$.jqplot.LogAxisRenderer | A plugin for a jqPlot to render a logarithmic axis.
axisDefaults | Default properties which will be applied directly to the series.
Properties | Properties
drawBaseline | True to draw the axis baseline.
minorTicks | Number of ticks to add between “major” ticks.

### axisDefaults

Default properties which will be applied directly to the series.

### Properties

Properties

base | the logarithmic base, commonly 2, 10 or Math.E
tickDistribution | Deprecated. “power” distribution of ticks always used. Option has no effect.

### drawBaseline

> this.drawBaseline = true

True to draw the axis baseline.

### minorTicks

> this.minorTicks = 'auto'

Number of ticks to add between “major” ticks. Major ticks are ticks supplied by user or auto computed. Minor ticks cannot be created by user.

> this.drawBaseline = true

True to draw the axis baseline.

> this.minorTicks = 'auto'

Number of ticks to add between “major” ticks.
Close